@@ -70,9 +70,12 @@ StatisticsDialog::StatisticsDialog(QWidget* aParent)
 
 
 	QMap<QString,int> nameToIdMap;
-	foreach ( DealerInfo * game, DealerInfoList::self()->games() )
-		foreach ( int id, game->distinctIds() )
+	const auto games = DealerInfoList::self()->games();
+	for (DealerInfo * game : games) {
+		const auto ids = game->distinctIds();
+		for (int id : ids)
 			nameToIdMap.insert( game->nameForId( id ), id );
+	}
 
 	QMap<QString,int>::const_iterator it = nameToIdMap.constBegin();
 	QMap<QString,int>::const_iterator end = nameToIdMap.constEnd();
@@ -124,7 +127,7 @@ void StatisticsDialog::setGameType(int gameIndex)
 	ui->LoseStreak->setText( QString::number( cg.readEntry(QStringLiteral("maxloosestreak%1").arg(gameIndex), 0)));
 	int minMoves = cg.readEntry(QStringLiteral("minmoves%1").arg(gameIndex), -1);
 	if(minMoves < 0)
-		ui->MinMoves->setText("∞");
+		ui->MinMoves->setText(QStringLiteral("∞"));
 	else
 		ui->MinMoves->setText(QString::number(minMoves));
 	unsigned int l = cg.readEntry(QStringLiteral("loosestreak%1").arg(gameIndex),0);
